@@ -3,6 +3,7 @@
 
 from planetary_computer.sas import (
     sign,
+    sign_inplace,
     sign_url,
     sign_item,
     sign_assets,
@@ -11,6 +12,7 @@ from planetary_computer.sas import (
 )
 from planetary_computer.settings import set_subscription_key
 
+from planetary_computer.version import __version__
 
 __all__ = [
     "set_subscription_key",
@@ -20,4 +22,5 @@ __all__ = [
     "sign_item",
     "sign_url",
     "sign",
+    "__version__",
 ]
